Index: apps/app_meetme.c
===================================================================
--- apps/app_meetme.c	(revision 8135)
+++ apps/app_meetme.c	(working copy)
@@ -1,3 +1,4 @@
+
 /*
  * Asterisk -- An open source telephony toolkit.
  *
@@ -881,6 +882,7 @@
 	char meetmesecs[30] = "";
 	char exitcontext[AST_MAX_CONTEXT] = "";
 	char recordingtmp[AST_MAX_EXTENSION] = "";
+	char members[10] = "";
 	int dtmf;
 	ZT_BUFFERINFO bi;
 	char __buf[CONF_SIZE + AST_FRIENDLY_OFFSET];
@@ -950,6 +952,10 @@
 	user->adminflags = 0;
 	user->talking = -1;
 	conf->users++;
+	/* Update table */
+	snprintf(members, sizeof(members), "%d", conf->users);
+	ast_update_realtime("meetme", "confno", conf->confno, "members", members , NULL);
+
 	ast_mutex_unlock(&conf->playlock);
 
 	if (confflags & CONFFLAG_EXIT_CONTEXT) {
@@ -1688,6 +1694,9 @@
 		          "<no name>", hr, min, sec);
 
 		conf->users--;
+		/* Update table */
+		snprintf(members, sizeof(members), "%d", conf->users);
+		ast_update_realtime("meetme", "confno", conf->confno, "members", members, NULL);
 		if (confflags & CONFFLAG_MARKEDUSER) 
 			conf->markedusers--;
 		if (!conf->users) {
@@ -1732,6 +1741,62 @@
 	return ret;
 }
 
+/*
+  This function looks for a conference via the RealTime module
+*/
+static struct ast_conference *find_conf_realtime(struct ast_channel *chan, char *confno, int make, int dynamic, char *dynamic_pin)
+{
+
+	struct ast_variable *var;
+	struct ast_conference *cnf = NULL;
+
+	/* Check first in the conference list */
+	ast_mutex_lock(&conflock);
+	cnf = confs;
+	while (cnf) {
+		if (!strcmp(confno, cnf->confno)) 
+			break;
+		cnf = cnf->next;
+	}
+	ast_mutex_unlock(&conflock);
+
+	if (!cnf) {
+		cnf = malloc(sizeof(struct ast_conference));
+		char *pin = NULL, *pinadmin = NULL; /* For temp use */
+		if (cnf) {
+			memset(cnf, 0, sizeof(struct ast_conference));
+			var = ast_load_realtime("meetme", "confno", confno, NULL);
+			while(var) {
+				if (!strcasecmp(var->name, "confno"))
+					ast_copy_string(cnf->confno, var->value, sizeof(cnf->confno));
+				if (!strcasecmp(var->name, "pin")) {
+					pin = (char*)malloc(strlen(var->value+1));
+					ast_copy_string(pin, var->value, sizeof(pin));
+				}
+				if (!strcasecmp(var->name, "adminpin")) {
+					pinadmin = (char*)malloc(strlen(var->value+1));
+					ast_copy_string(pinadmin, var->value, sizeof(pinadmin));
+				}
+				var = var->next;
+			}
+			if (pin) {
+				if (pinadmin)
+					cnf = build_conf(confno, pin, pinadmin, make, dynamic);
+				else
+					cnf = build_conf(confno, pin, "", make, dynamic);
+			} else {
+				if (pinadmin)
+					cnf = build_conf(confno, "", pinadmin, make, dynamic);
+				else
+					cnf = build_conf(confno, "", "", make, dynamic);
+			}
+		}
+	}
+
+	return cnf;
+}
+
+
 static struct ast_conference *find_conf(struct ast_channel *chan, char *confno, int make, int dynamic, char *dynamic_pin)
 {
 	struct ast_config *cfg;
@@ -2038,6 +2103,9 @@
 			/* Check the validity of the conference */
 			cnf = find_conf(chan, confno, 1, dynamic, the_pin);
 			if (!cnf) {
+				cnf = find_conf_realtime(chan, confno, 1, dynamic, the_pin);
+			}
+			if (!cnf) {
 				res = ast_streamfile(chan, "conf-invalid", chan->language);
 				if (!res)
 					ast_waitstream(chan, "");
